@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The CGI utility of the abstract database API
- *                                                      Copyright (C) 2006-2009 Mikio Hirabayashi
+ *                                                      Copyright (C) 2006-2010 Mikio Hirabayashi
  * This file is part of Tokyo Cabinet.
  * Tokyo Cabinet is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -112,13 +112,13 @@ int main(int argc, char **argv){
   if(params.page < 1) params.page = 1;
   bool wmode;
   switch(params.action){
-  case ACTPUT:
-  case ACTOUT:
-    wmode = true;
-    break;
-  default:
-    wmode = false;
-    break;
+    case ACTPUT:
+    case ACTOUT:
+      wmode = true;
+      break;
+    default:
+      wmode = false;
+      break;
   }
   TCADB *db = tcadbnew();
   char path[strlen(DBNAME)+16];
@@ -133,18 +133,18 @@ int main(int argc, char **argv){
   if(tcadbsize(db) > 0){
     if(wmode) tcadbtranbegin(db);
     switch(params.action){
-    case ACTLIST:
-    case ACTLISTVAL:
-    case ACTPUT:
-    case ACTOUT:
-      dolist(&params, db);
-      break;
-    case ACTGET:
-      doget(&params, db);
-      break;
-    default:
-      doerror(400, "no such action");
-      break;
+      case ACTLIST:
+      case ACTLISTVAL:
+      case ACTPUT:
+      case ACTOUT:
+        dolist(&params, db);
+        break;
+      case ACTGET:
+        doget(&params, db);
+        break;
+      default:
+        doerror(400, "no such action");
+        break;
     }
     if(wmode) tcadbtrancommit(db);
   } else {
@@ -359,7 +359,8 @@ static void sethtmlheader(PARAMS *params, TCXSTR *obuf, TCADB *db){
   XP("body { margin :0em; padding: 0.5em 1em; background: #eeeeee; color: #111111; }\n");
   XP("h1 { margin: 3px; padding: 0px; font-size: 125%%; }\n");
   XP("h1 a { color: #000000; }\n");
-  XP("hr { margin: 0px 0px; height: 1px; border: none; background: #999999; color: #999999; }\n");
+  XP("hr { margin: 0px 0px; height: 1px; border: none;"
+     " background: #999999; color: #999999; }\n");
   XP("form { margin: 5px; padding: 0px; }\n");
   XP("#list { margin: 5px; padding: 0px; }\n");
   XP("p { margin: 5px; padding: 0px; }\n");
@@ -447,18 +448,18 @@ static void sethtmlrecval(const char *kbuf, int ksiz, TCXSTR *obuf, TCADB *db){
     if(c >= 0x20 && c <= 0x7e){
       if(hex) tcxstrcat(obuf, " ", 1);
       switch(c){
-      case '<':
-        tcxstrcat(obuf, "&lt;", 4);
-        break;
-      case '>':
-        tcxstrcat(obuf, "&gt;", 4);
-        break;
-      case '&':
-        tcxstrcat(obuf, "&amp;", 5);
-        break;
-      default:
-        tcxstrcat(obuf, vbuf + j, 1);
-        break;
+        case '<':
+          tcxstrcat(obuf, "&lt;", 4);
+          break;
+        case '>':
+          tcxstrcat(obuf, "&gt;", 4);
+          break;
+        case '&':
+          tcxstrcat(obuf, "&amp;", 5);
+          break;
+        default:
+          tcxstrcat(obuf, vbuf + j, 1);
+          break;
       }
       width--;
       hex = false;
